@@ -36,6 +36,17 @@
 
 
 class KRecentFilesAction;
+#if 0
+class KActionMenu;
+class QAction;
+class QLabel;
+class QDockWidget;
+
+class Dashboard;
+class StatisticsMainWindow;
+class ScriptManager;
+class ParleyPracticeMainWindow;
+#endif
 
 
 class ParleyMainWindow : public KXmlGuiWindow
@@ -63,7 +74,7 @@ public:
     void initActions();
 
     /** add a new entry to the list of recent files */
-    void addRecentFile(const KUrl &url, const QString &name);
+    void addRecentFile(const QUrl &url, const QString &name);
 
     /** save the app-specific options on slotAppExit or by an Options dialog */
     void saveOptions();
@@ -96,7 +107,7 @@ public slots:
     bool queryClose();
 
     /** remove an entry from the list of recent files */
-    void removeRecentFile(const KUrl &url);
+    void removeRecentFile(const QUrl &url);
 
     QSize sizeHint() const;
 
@@ -142,7 +153,7 @@ signals:
     void preferencesChanged();
 
 private:
-    ParleyMainWindow(const KUrl &filename = KUrl());
+    ParleyMainWindow(const QUrl &filename = QUrl());
     static ParleyMainWindow *s_instance;
 
     Component      m_currentComponent;
